@@ -1,4 +1,4 @@
-/* Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 /* Header files */
 #define HAVE_ALLOCA_H 1
 #define HAVE_ARPA_INET_H 1
+#define HAVE_CRYPT_H 1
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_FPU_CONTROL_H 1
@@ -199,6 +200,7 @@
 #define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_SYNC_BUILTINS 1
 /* #undef HAVE_VALGRIND */
+/* #undef HAVE_PTHREAD_THREADID_NP */
 
 /* IPV6 */
 /* #undef HAVE_NETINET_IN6_H */
@@ -254,7 +256,7 @@
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.21-21/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.21-21/plugin/keyring_vault/tests;/build/percona-server/src/percona-server-5.7.21-21/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.21-21/plugin/scalability_metrics/tests"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.22-22/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.22-22/plugin/keyring_vault/tests;/build/percona-server/src/percona-server-5.7.22-22/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.22-22/plugin/scalability_metrics/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/doc/percona-server"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/doc/percona-server"
@@ -391,15 +393,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 21
-#define MYSQL_VERSION_EXTRA "-21"
+#define MYSQL_VERSION_PATCH 22
+#define MYSQL_VERSION_EXTRA "-22"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.21-21"
+#define PACKAGE_STRING "MySQL Server 5.7.22-22"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.21-21"
-#define VERSION "5.7.21-21"
+#define PACKAGE_VERSION "5.7.22-22"
+#define VERSION "5.7.22-22"
 #define PROTOCOL_VERSION 10
 
 /*
